Fiscal Policy Models 
===================== 
 
This section includes planned models for fiscal policy analysis. Contributions are welcome! 
 
- Taxation and Government Spending Models 
- Budget Deficit Models 
- Public Debt Models 
- Fiscal Multiplier Models 
- Laffer Curve 
- Ricardian Equivalence 
